Welcome to gen-trie’s documentation! — gen-tries 0.3.2 documentation

# Welcome to gen-trie’s documentation!

gen-trie is a Python library for creating and manipulating ‘generalized’ trie data structures.

Unlike common trie implementations that only support strings as keys, this generalized trie can handle various types of tokens in keys, as long as they are hashable.

Check out the Using gen-trie section for further information, including how to do Installation of the project.

Note

This project is under active development.

## Contents

- Using gen-trie
  - Installation
  - Usage
- gentrie package
  - Module contents
    - `GeneralizedKey`
    - `GeneralizedTrie`
      - `GeneralizedTrie.add()`
      - `GeneralizedTrie.clear()`
      - `GeneralizedTrie.items()`
      - `GeneralizedTrie.keys()`
      - `GeneralizedTrie.prefixes()`
      - `GeneralizedTrie.remove()`
      - `GeneralizedTrie.suffixes()`
      - `GeneralizedTrie.values()`
    - `Hashable`
    - `InvalidGeneralizedKeyError`
    - `InvalidHashableError`
    - `TrieEntry`
      - `TrieEntry.ident`
      - `TrieEntry.key`
    - `TrieId`
    - `is_generalizedkey()`
    - `is_hashable()`